import re, os, os.path, commands
from django.http import HttpResponseForbidden, HttpResponseRedirect
from django.utils.translation import ugettext as _
from django.core.urlresolvers import reverse
from django.contrib import messages
from jumbo.utils.functions import get_settings
from jumbo.shortcuts import render_to_response, render_to_string
from organization.models import Organization, Contact


def save_in_addressbook(request):
    if not request.user.has_perm("organization.save_addressbook"):
        return HttpResponseForbidden(render_to_string('admin/forbidden.html'))

    # Controllo che ci sia installata l'applicazione Asterisk per andare poi a 
    # recuperare i vari interni
    try:
        from asterisk.models import AsteriskProfile, AsteriskAddressBook
    except Exception, e:
        return render_to_response('admin/generic_error.html', error=_("You must enable the Asterisk Application."))

    # Controllo se ha l'opzione per poter aggiornare i telefoni dalla rubrica
    has_sipphone = get_settings("organization.settings", "HAS_SIPPHONE")

    if not has_sipphone:
        return render_to_response('admin/generic_error.html', error=_("You don't have this feature enable."))

    qs_org = Organization.objects.filter(in_addressbook=True)
    qs_ast_profile = AsteriskProfile.objects.all()
    qs_ast_book = AsteriskAddressBook.objects.all()
    total_num = len(qs_org) + len(qs_ast_profile) + len(qs_ast_book)

    if request.method == 'POST':
        real_save_in_addressbook(request, qs_org, qs_ast_profile, qs_ast_book)
    else:
        return render_to_response('admin/organization/organization/confirm_save_in_addressbook.html', 
                                  qs_org=qs_org, qs_ast_profile=qs_ast_profile,
                                  qs_ast_book=qs_ast_book, total_num=total_num)
    return HttpResponseRedirect(reverse('admin:organization_organization_changelist'))


def real_save_in_addressbook(request, qs_org, qs_ast_profile, qs_ast_book):
    from asterisk.utils import clean_number

    try:
        import lxml.etree as ET
    except ImportError:
        import elementtree.ElementTree as ET

    directory = ET.Element("directory")
    directory.text = "\n  "
    item_list = ET.SubElement(directory, "item_list")
    item_list.text = "\n    "
    item_list.tail = "\n"

    i = 1
    for profile in qs_ast_profile:
        item = ET.SubElement(item_list, "item")
        item.text = "\n      "
        item.tail = "\n  "
        # last name
        ln = ET.SubElement(item, "ln")
        ln.text = "%s" % profile.profile_name
        ln.tail = "\n      "
        # first name
        fn = ET.SubElement(item, "fn")
        fn.tail = "\n      "
        # contact
        ct = ET.SubElement(item, "ct")
        ct.text = clean_number(profile.internal_number, add_internal_prefix=False)
        ct.tail = "\n      "
        # speed dial
        sd = ET.SubElement(item, "sd")
        sd.text = "%s" % i
        sd.tail = "\n      "
        # ring tone
        rt = ET.SubElement(item, "rt")
        rt.tail = "\n      "
        # buddy watch
        bw = ET.SubElement(item, "bw")
        bw.text = "1"
        bw.tail = "\n      "
        # bb
        bb = ET.SubElement(item, "bb")
        bb.text = "0"
        bb.tail = "\n    "
        i += 1

    for profile in qs_ast_book:
        item = ET.SubElement(item_list, "item")
        item.text = "\n      "
        item.tail = "\n  "
        # last name
        ln = ET.SubElement(item, "ln")
        ln.text = "%s" % profile.description
        ln.tail = "\n      "
        # first name
        fn = ET.SubElement(item, "fn")
        fn.tail = "\n      "
        # contact
        ct = ET.SubElement(item, "ct")
        ct.text = clean_number(profile.phone_number, add_internal_prefix=not profile.is_internal)
        ct.tail = "\n      "
        # speed dial
        sd = ET.SubElement(item, "sd")
        sd.text = "%s" % i
        sd.tail = "\n      "
        # ring tone
        rt = ET.SubElement(item, "rt")
        rt.tail = "\n      "
        # buddy watch
        bw = ET.SubElement(item, "bw")
        bw.text = "1"
        bw.tail = "\n      "
        # bb
        bb = ET.SubElement(item, "bb")
        bb.text = "0"
        bb.tail = "\n    "
        i += 1

    for q in qs_org:
        item = ET.SubElement(item_list, "item")
        item.text = "\n      "
        item.tail = "\n  "
        # last name
        ln = ET.SubElement(item, "ln")
        ln.text = q.name
        ln.tail = "\n      "
        # first name
        fn = ET.SubElement(item, "fn")
        fn.tail = "\n      "
        # contact
        ct = ET.SubElement(item, "ct")
        ct.text = clean_number(q.phone)
        ct.tail = "\n      "
        # speed dial
        sd = ET.SubElement(item, "sd")
        sd.tail = "\n      "
        # ring tone
        rt = ET.SubElement(item, "rt")
        rt.tail = "\n      "
        # buddy watch
        bw = ET.SubElement(item, "bw")
        bw.text = "1"
        bw.tail = "\n      "
        # bb
        bb = ET.SubElement(item, "bb")
        bb.text = "0"
        bb.tail = "\n    "
    tree = ET.ElementTree(directory)

    re_name = re.compile('.+-directory.xml')
    dir_phone = get_settings("organization.settings", "PATH_ADDRESSBOOK")
    asterisk_host = get_settings("asterisk.settings", "ASTERISK_HOST")
    for f in os.listdir(dir_phone):
        path_f = os.path.join(dir_phone, f)
        if not os.path.isdir(path_f):
            # Se il nome del file e' macaddresstelefono-directory.xml che rappresentano
            # i file con le voci che verranno caricati nella rubrica dei vari telefoni
            if re_name.match(f):
                tree.write(path_f)
    
    for profile in AsteriskProfile.objects.all():
        if profile.internal_number and profile.internal_number.isdigit():
            restart_phone = "sudo ssh root@%s \"asterisk -rx 'sip notify polycom-check-cfg %s'\"" % (
                                                        asterisk_host,
                                                        profile.internal_number)
            status, output = commands.getstatusoutput(restart_phone)

    messages.info(request, _("The address book was succesfully updated."))