# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _
from django.conf.urls.defaults import *
from django import forms

from jumbo.forms.models import AdminModelForm
from jumbo.admin.options import OrderedModelAdmin, ExtendibleModelAdmin
from jumbo.core.urlresolvers import reverse
from jumbo.forms import DateWidget
#from jumbo.utils.csv import render_csv

from payment.models import PaymentForm, PaymentInstallment

### INLINE
class PaymentInstallmentInline(admin.TabularInline):
    model = PaymentInstallment
    extra = 0
    fk_name = 'payment_form'
    fields = ('amount', 'days', 'end_month', 'days_end_month', 'discount', 'fee')

### SEARCH
class PaymentFormSearchForm(forms.ModelForm):
    class Meta:
        model = PaymentForm
        fields = ['code']
        display_fields = (('status', 'code', 'name__istartswith'),)
    def __init__(self, *args, **kws):
        super(PaymentFormSearchForm, self).__init__(*args, **kws)
        STATUS = (('', '-'*9), ('1', _('Active')), ('0', _('Inactives')),)

        self.fields['status'] = forms.ChoiceField(label=_("Status"), choices=STATUS, required=False)
        self.fields['name__istartswith'] = forms.CharField(label=_("Name"), required=False)

class PaymentInstallmentSearchForm(forms.ModelForm):
    class Meta:
        model = PaymentInstallment
        fields = ['code']
        display_fields = (('status', 'code', 'name__istartswith'),)
    def __init__(self, *args, **kws):
        super(PaymentInstallmentSearchForm, self).__init__(*args, **kws)
        STATUS = (('', '-'*9), ('1', _('Active')), ('0', _('Inactives')),)

        self.fields['status'] = forms.ChoiceField(label=_("Status"), choices=STATUS, required=False)
        self.fields['name__istartswith'] = forms.CharField(label=_("Name"), required=False)

### GENERAL
########################################
# PAYMENT FORM                         #
########################################
class PaymentFormAdmin(ExtendibleModelAdmin):
    class Media:
        css = {"all": ("payment/css/admin_payment.css",)}
    search_form = PaymentFormSearchForm
    fieldsets = (
        (_('logs admin'), {'fields': (('creator', 'date_create',), ('last_modifier', 'date_last_modify',)), 'classes': ('collapse',)}),
        (_('visualization admin'), {'fields': ('ordering',), 'classes': ('collapse',),}),
        (_('general admin'), {'fields': ('status', ('code', 'name'), 'description', ('fee', 'discount'))}),
    )
    search_fields = ['name']
    list_display = ('get_status_icon', 'get_object_error', 'name', 'fee', 'discount', 'get_edit_icon', 'get_delete_icon')
    list_display_csv = ('status', 'code', 'name')
    inlines = [PaymentInstallmentInline,]
    save_as = True
    save_on_top = True

    def get_object_error(self, result):
        ## per bordare di rosso i pagamenti con rate errate
        code = result.code
        tot_amount = 0
        for installment in result.installments.all():
            tot_amount += installment.amount
        if tot_amount != 100:
            code = "<span class='object_error'>%s</span>" % result.code
        return code
    get_object_error.allow_tags = True
    get_object_error.short_description = _("Code")

class PaymentInstallmentAdmin(ExtendibleModelAdmin):
    class Media:
        css = {"all": ("payment/css/admin_payment.css",)}
    search_form = PaymentInstallmentSearchForm
    fieldsets = (
        (_('logs admin'), {'fields': (
            ('creator', 'date_create',),
            ('last_modifier', 'date_last_modify',)
        ), 'classes': ('collapse',)}),
        (_('visualization admin'), {'fields': ('ordering',), 'classes': ('collapse',),}),
        (_('general admin'), {'fields': (
            'status', ('code', 'name'),
            'description', 'payment_form',
            ('amount', 'days',),
            ('end_month', 'days_end_month',),
            ('fee', 'discount'),
        ),},),
    )
    search_fields = ['name']
    list_display = (
        'get_status_icon', 'payment_form', 'code', 'name', 'amount', 'days', 'end_month',
        'days_end_month', 'get_edit_icon', 'get_delete_icon'
    )
    list_display_csv = (
        'status', 'code', 'name', 'amount', 'days',
        'end_month', 'days_end_month'
    )
    ordering = ['ordering', 'code']
    save_as = True
    save_on_top = True

admin.site.register(PaymentForm, PaymentFormAdmin)
admin.site.register(PaymentInstallment, PaymentInstallmentAdmin)
