# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import ugettext_lazy as _
from jumbo.db.models import DateModel, UserModel, StatusModel, OrderedModel

####################################
# PAGAMENTO FORMA                  #
####################################
class PaymentForm (DateModel, UserModel, StatusModel, OrderedModel):
    ## Campi Generici
    ## ForeignKey
    ## Campi
    code = models.CharField (
        unique = True,
        max_length = 25,
        db_index = True,
        verbose_name = _("code"),
    )
    name = models.CharField (
        unique = True,
        max_length = 100,
        db_index = True,
        verbose_name = _("name"),
    )
    description = models.TextField (
        blank = True, null = True,
        verbose_name = _("description"),
    )
    fee = models.DecimalField (
        max_digits = 9,
        decimal_places = 2,
        default = 0,
        verbose_name = _("fee"),
    )
    discount = models.DecimalField (
        max_digits = 9,
        decimal_places = 2,
        default = 0,
        verbose_name = _("discount"),
    )

    class Meta:
        verbose_name = _("payment form")
        verbose_name_plural = _("payment forms")
        ordering = ('code',)
        permissions = (
            ("view_paymentform"    , "Can view payment form"),
        )

    def __unicode__(self):
        return u"%s - %s" % (self.code, self.name)

###################################
# RATA PAGAMENTO                  #
###################################
class PaymentInstallment (DateModel, UserModel, StatusModel, OrderedModel):
    ## Campi Generici
    ## ForeignKey
    payment_form = models.ForeignKey(
        'PaymentForm',
        related_name = "installments",
        db_index = True,
        verbose_name = _("payment form"),
    )
    ## Campi
    code = models.CharField (
        unique = True,
        blank = True, null = True,
        max_length = 35,
        db_index = True,
        verbose_name = _("code"),
    )
    name = models.CharField (
        unique = True,
        blank = True, null = True,
        max_length = 110,
        db_index = True,
        verbose_name = _("name"),
    )
    description = models.TextField (
        blank = True, null = True,
        verbose_name = _("description"),
    )
    amount = models.IntegerField (
        default = 100,
        verbose_name = _("amount %"),
    )
    days = models.IntegerField (
        default = 0,
        verbose_name = _("days"),
    )
    end_month = models.BooleanField (
        db_index = True,
        verbose_name = _("end month"),
    )
    # Giorni aggiuntivi oltre il fine mese.
    # Viene utilizzato solo se end_month è uguale a True e viene sommato alla
    # data di scadenza calcolata
    days_end_month = models.IntegerField (
        default = 0,
        verbose_name = _("days after end month"),
    )
    discount = models.DecimalField (
        max_digits = 4,
        decimal_places = 2,
        default = 0.00,
        verbose_name = _("discount"),
    )
    fee = models.DecimalField (
        max_digits = 4,
        decimal_places = 2,
        default = 0.00,
        verbose_name = _("fee"),
    )

    def save(self):
        if not self.code:
            self.code = "%s_%s_%s" % (
                self.payment_form.code, self.amount, self.days
            )
        if not self.name:
            self.name = unicode(
                "Codice Pagamento: %s %s%% %s gg."
            ) % (
                self.payment_form.code, self.amount, self.days
            )
        super(PaymentInstallment, self).save()

    class Meta:
        verbose_name = _("payment installment")
        verbose_name_plural = _("payment installments")
        ordering = ('code',)
        permissions = (
            ("view_paymentinstallment"    , "Can view payment installment"),
        )

    def __unicode__(self):
        return u"%(code)s - %(name)s" % {'code': self.code, 'name': self.name}

    def get_full_name(self):
        return u"%s %s" % (self.payment_form.name, self.days)
    full_name = property(get_full_name)
